@@ -14,7 +14,7 @@ for my $sql(<DATA>) {
 }
 __DATA__
 CREATE TABLE foo ( id INTEGER UNIQUE, phrase VARCHAR(40) UNIQUE )
-CREATE TABLE foo ( id INTEGER PRIMARY KEY, phrase VARCHAR(40) PRIMARY KEY )
+CREATE TABLE foo ( id INTEGER PRIMARY KEY, phrase VARCHAR(40) UNIQUE )
 CREATE TABLE foo ( id INTEGER NOT NULL, phrase VARCHAR(40) NOT NULL )
 SELECT * FROM foo WHERE TRIM( UPPER(phrase) ) = 'bar'
 SELECT * FROM foo WHERE a = b AND ( c = d OR e = f)
